[commit: ghc] master: Typos in comments (3f20da1)

git at git.haskell.org git at git.haskell.org
Fri May 27 15:07:19 UTC 2016


Repository : ssh://git@git.haskell.org/ghc

On branch  : master
Link       : http://ghc.haskell.org/trac/ghc/changeset/3f20da1c569561248ad6282111df2a2d42f34768/ghc

>---------------------------------------------------------------

commit 3f20da1c569561248ad6282111df2a2d42f34768
Author: Gabor Greif <ggreif at gmail.com>
Date:   Fri May 27 17:09:33 2016 +0200

    Typos in comments


>---------------------------------------------------------------

3f20da1c569561248ad6282111df2a2d42f34768
 compiler/simplStg/UnariseStg.hs | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/compiler/simplStg/UnariseStg.hs b/compiler/simplStg/UnariseStg.hs
index 9eca768..d580942 100644
--- a/compiler/simplStg/UnariseStg.hs
+++ b/compiler/simplStg/UnariseStg.hs
@@ -24,7 +24,7 @@ Suppose that a variable x : (# t1, t2 #).
 
   * At the binding site for x, make up fresh vars  x1:t1, x2:t2
 
   * Extend the UniariseEnv   x :-> [x1,x2]
 
   * Replace the binding with a curried binding for x1,x2
        Lambda:   \x.e                ==>   \x1 x2. e
@@ -45,7 +45,7 @@ Suppose that a variable x : (# t1, t2 #).
     I think we rely on the code generator to short-circuit this
     case without generating any actual code.
 
-Of course all this applies recursively, so that we flattn out nested tuples.
+Of course all this applies recursively, so that we flatten out nested tuples.
 
 Note [Unarisation and nullary tuples]
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -60,7 +60,7 @@ The above scheme has a special cases for nullary unboxed tuples, x :: (# #)
   * If we find (# #) as an argument all by itself
        f ...(# #)...
     it looks like an Id, so we look up in UnariseEnv. We want to replace it
-    with voidPrimId, so the convenient thing is to initalise the UniariseEnv
+    with voidPrimId, so the convenient thing is to initalise the UnariseEnv
     with   (# #) :-> [voidPrimId]
 
 See also Note [Nullary unboxed tuple] in Type.hs.
@@ -24,7 +24,7 @@ Suppose that a variable x : (# t1, t2 #).
   * At the binding site for x, make up fresh vars  x1:t1, x2:t2
 
-  * Extend the UniariseEnv   x :-> [x1,x2]
+  * Extend the UnariseEnv   x :-> [x1,x2]
 
   * Replace the binding with a curried binding for x1,x2



More information about the ghc-commits mailing list